abacusai.pipeline_version_logs — AbacusAI documentation

# abacusai.pipeline_version_logs

## Classes

`PipelineStepVersionLogs` | Logs for a given pipeline step version.
`AbstractApiClass` |
`PipelineVersionLogs` | Logs for a given pipeline version.

## Module Contents

class abacusai.pipeline_version_logs.PipelineStepVersionLogs(client, stepName=None, pipelineStepId=None, pipelineStepVersion=None, logs=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Logs for a given pipeline step version.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - stepName (str) – The name of the step

    - pipelineStepId (str) – The ID of the step

    - pipelineStepVersion (str) – The version of the step

    - logs (str) – The logs for both stdout and stderr of the step

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

class abacusai.pipeline_version_logs.AbstractApiClass(client, id)
  __eq__(other)

    Return self==value.

  _get_attribute_as_dict(attribute)

class abacusai.pipeline_version_logs.PipelineVersionLogs(client, stepLogs={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Logs for a given pipeline version.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - stepLogs (PipelineStepVersionLogs) – A list of the pipeline step version logs.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict